****************************
Mopidy Radio Rough
****************************

Rough gui for listening to internet. 

Installation
============

Install by running::

    pip install Mopidy-Radio-Rough


Configuration
=============

Once installed it will work, you ca disable it by setting enabled=false in [radio_rough] section of mopidy.conf.

Project resources
=================

- `Source code <https://github.com/unusual.computers/mopidyroughradio>`_
- `Issue tracker <https://github.com/unusual.computers/mopidyroughradio/issues>`_


Credits
=======

- Original author: `Unusual Computers <https://github.com/unusual.computers`__
- Current maintainer: `Unusual Computers <https://github.com/unusual.computers`__
- `Contributors <https://github.com/unusual.computers/mopidyroughradio/graphs/contributors>`_


Changelog
=========

v0.1.0 (UNRELEASED)
----------------------------------------

- Initial release.
